@@ -1,4 +1,7 @@
 import  json 
+from jsonschema import validate as json_schema_validate
+from jsonschema.exceptions import ValidationError
+
 
 from zohavi.zwebui.web_field import WebField
 from zohavi.zbase.staple import ZStaple
@@ -12,14 +15,49 @@ class DataUIModel(ZStaple):
 
 		super().__init__(app = None, logger = logger )
 
+		DataUIModel.validate_schema( form_field_validation_schema )
+
 		# self.update_obj_list = update_obj
 		self.data_schema = form_field_validation_schema 
+		
 		self.web_schema = WebField( form_field_validation_schema, logger=logger )
 		# self.logger = logger
 		self.session = session
 
 		# pass
+	@staticmethod
+	def validate_schema( json_input_schema):
+		validation_schema = {
+							"type": "array",
+							"items": 
+							{ 	"type" : "object",
+								"properties" : 
+								{ "module_name":{"type":"string" },
+									"table_obj":{"type":"string" },
+									"fields": 
+									{ "type": "object",
+										"patternProperties": 
+										{	".*": 
+											{ 	"type": "object",
+												"properties": 
+												{ 	"field_db":{"type":"string" },
+													"key":{"type":"boolean" },
+													"validation":{
+																	"type": "object",
+																	"properties": {
+																					"required":{"type":"boolean"},
+																					"text_min_len":{"type":"integer"},
+																					"text_max_len":{"type":"integer"}
+								} 	}	}	}	}	}	}	}
+							}
+		try:
+			json_schema_validate( instance= json_input_schema , schema=validation_schema   )
+		except  Exception as e:
+			print(e)
+			return False
 
+		return True
+ 
 	#####################################################################################
 	def get_webfield_value( self, web_data, field_html_name):
 		for field in web_data:	
@@ -43,14 +81,14 @@ class DataUIModel(ZStaple):
 
 	#####################################################################################
 	def _data_validate( self, submit_data ): 
-		validate_fail_reason = None
+		validate_fail_reason = {}
 		self.log_debug("validating data")
 		self.log_debug( submit_data )
 
 		if self.web_schema.validate(  submit_data, validate_fail_reason ):
 			self.log_debug('validation ok')
 			return True
-		self.log_debug("****:" + validate_fail_reason)
+		self.log_debug("****:" + json.dumps( validate_fail_reason) )
 		return False
 
 	#####################################################################################
@@ -151,7 +189,9 @@ class DataUIModel(ZStaple):
 			data_obj = None
 
 			#Search to see if the record exists
-			if db_fields['keys']: data_obj = self.session.query( data_class_ref ).filter_by( **db_fields['keys'] ).first()
+			if db_fields['keys']: 
+				# breakpoint()
+				data_obj = self.session.query( data_class_ref ).filter_by( **db_fields['keys'] ).first()
 			
 			if data_obj:  #If found, then update fields
 				for db_field_name in db_fields['fields']:
