@@ -10,7 +10,7 @@
 
 
  
-    class WCTable extends WCFormControl { 
+    export default class WCTable extends WCFormControl { 
         define_template_globals(){
             return `:host{ 
                         --table_header_cell_color: var(--background_cat3_color);
