@@ -25,9 +25,21 @@ site_update_schema = {
 								"fields":{
 											"si_env_id":{"field_db":"id",   "key":True},
 											"si_env_name":{"field_db":"env_name", "validation":{"required":True, "text_min_len":3, "text_max_len":20} },
-											"si_env_code":{"field_db":"env_code", "validation":{"required":True,  "text_max_len":5} },
+											"si_env_code":{"field_db":"env_code", "validation":{"required":True,  "text_max_len":10} },
 											"si_env_desc":{"field_db":"env_desc", "validation":{"required":False,  "text_max_len":200} }
 								}
+							}],
+							"SiteEnvSetting":[{ 	
+								"module_name":"test_wc",
+								"table_obj": "SiteEnv",
+								"fields":{
+											"si_env_id":{"field_db":"id",   "key":True},
+											"si_env_cs":{"field_db":"env_cs", "validation":{"required":True} },
+											"si_env_authlogon":{"field_db":"env_authlogon", "validation":{"required":True} },
+											"si_env_authsite_name":{"field_db":"env_authsite_name", "validation":{"required":False,  "text_max_len":10} },
+											"si_env_authmethod":{"field_db":"env_auth_method", "validation":{"required":False} },
+											
+								}
 							}]
 					}
 
@@ -73,6 +85,12 @@ class SiteEnv( db.Model ,  TBL_Default):
 	env_name = Column(String(100) ) 
 	env_desc = Column(String(200) ) 
 	env_code = Column(String(5) )  
+	env_cs = Column(String(5) )  
+	env_authlogon = Column(String(5) )  
+	env_authsite_name = Column(String(5) )  
+	env_auth_method = Column(String(5) )  
+
+
 
 db.create_all()
 # db.session.add( SiteEnv(env_name='dev', env_desc='Twitter Bot', env_code='dev1') )
@@ -125,6 +143,12 @@ def test_group( ):
 	data_ui = DataUIModel(  site_update_schema['SiteEnv'] , db.session, logger )
 	return render_template( 'test_group.html', data_ui=data_ui)
 
+#################################################################
+@app.route('/test/group/save', methods=['POST' ] )
+def test_group_save( ):
+	data_ui = DataUIModel(  site_update_schema['SiteEnvSetting'] , db.session, logger )
+	return data_ui.data_update_ajax( request.json )
+
 #################################################################
 @app.route("/test/table/ajax_add", methods=["POST"])
 def test_table_add():
